@@ -7,7 +7,7 @@ use CPAN::Changes::Release;
 use Scalar::Util ();
 use version      ();
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 # From DateTime::Format::W3CDTF
 our $W3CDTF_REGEX = qr{(\d\d\d\d) # Year
@@ -249,9 +249,9 @@ sub add_release {
     my $self = shift;
 
     for my $release ( @_ ) {
-        $release = CPAN::Changes::Release->new( %$release )
-            if !Scalar::Util::blessed $release;
-        $self->{ releases }->{ $release->version } = $release;
+        my $new = Scalar::Util::blessed $release ? $release
+            : CPAN::Changes::Release->new( %$release );
+        $self->{ releases }->{ $new->version } = $new;
     }
 }
 
